<?php
/*
Plugin Name: Flat PM
Plugin URI: https://mehanoid.pro/flat-pm/
Description: Плагин для вывода рекламы и интерактивного контента. Увеличиваем конверсию, поведенческие факторы и выхлоп с сайтов! <a href="https://t.me/joinchat/UUXPMRJR9zRJUjzx">Канал в телеграм</a>
Version: 2.670
Author: Михаил Flat
Author URI: https://mehanoid.pro/
Text Domain: flatpm
Domain Path: /l10n
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}


define( 'FLATPM_SLUG', dirname( plugin_basename( __FILE__ ) ) );
define( 'FLATPM_VERSION', '?2.670' );
define( 'FLATPM_INT_MAX', PHP_INT_MAX - 100 );
define( 'FLATPM_URL', plugin_dir_url( __FILE__ ) );
define( 'FLATPM_DIR', __DIR__ );
define( 'FLATPM_PATH', 'path' );
define( 'FLATPM_UPPD', FLATPM_DIR . '/' . FLATPM_PATH . '/updater' );
define( 'FLATPM_FUNC', FLATPM_DIR . '/' . FLATPM_PATH . '/functions' );
define( 'FLATPM_NEWS', FLATPM_DIR . '/' . FLATPM_PATH . '/form_news/news.php' );
define( 'FLATPM_L10N', 'flatpm' );
define( 'FLATPM_LOGO', include_once 'assets/img/flat_pm.svg.php' );


include_once FLATPM_FUNC . '/flat-core.php';
include_once FLATPM_FUNC . '/flat-ajax_admin.php';
include_once FLATPM_FUNC . '/flat-ajax_front.php';
include_once FLATPM_FUNC . '/flat-shortcode.php';
include_once FLATPM_FUNC . '/flat-scripts.php';
include_once FLATPM_FUNC . '/flat-header_footer.php';
include_once FLATPM_FUNC . '/flat-filter_content.php';


class FlatPM_Obj{
	function __construct(){
		add_action( 'admin_enqueue_scripts', function( $suffix ){
			$accept_array = array(
				'toplevel_page_blocks_form',
				'flat-pm_page_add_blocks_form',
				'flat-pm_page_header_footer',
				'flat-pm_page_sliders_form',
				'flat-pm_page_video_form',
				'flat-pm_page_block_ip_form',
				'flat-pm_page_settings_form',
				'flat-pm_page_export_import',
				'flat-pm_page_license_form',
			);

			if( !in_array( $suffix, $accept_array ) )
				return;

			wp_enqueue_style( 'flat_pm', FLATPM_URL . 'assets/back/style.css', array(), FLATPM_VERSION, 'all' );
			wp_enqueue_style( 'flat_pm_codemirror', FLATPM_URL . 'assets/back/codemirror.css', array(), FLATPM_VERSION, 'all' );
			wp_enqueue_style( 'flat_pm_Fira-Code', 'https://fonts.googleapis.com/css2?family=Fira+Code:wght@500&display=swap', array(), FLATPM_VERSION, 'all' );
			wp_enqueue_style( 'editor-buttons' );

			wp_enqueue_script( 'flat_pm', FLATPM_URL . 'assets/back/js.js', array( 'jquery', 'wp-color-picker' ), FLATPM_VERSION, false );

			$args = array(
				'type' => 'text/html',
				'codemirror' => array(
					'theme' => 'material'
				)
			);

			$settings = wp_enqueue_code_editor( $args );

			if ( false === $settings ) {
				return;
			}

			wp_add_inline_script(
				'code-editor',
				sprintf( '
					jQuery( function($){
						$(\'textarea[id^="sub_block_"],textarea[id^="flat_settings_"],textarea[id^="flat_pm_check_video_"]\').each( function(){
							var textArea = this,
								editor = wp.codeEditor.initialize( textArea, %s );

							editor.codemirror.on( \'change\', function(){
								editor.codemirror.save();
								$( textArea ).trigger( \'flatpm_change\' );
							} );

							$(textArea).on( \'change\', function(){
								editor.codemirror.setValue(this.value);
								$( textArea ).trigger( \'flatpm_change\' );
							} );
						} );
					} );',
					wp_json_encode( $settings )
				)
			);
		} );

		add_action( 'admin_menu', array( &$this, 'flat_admin' ) );

		add_action( 'admin_head', 'flat_pm_admin_head' );
		function flat_pm_admin_head(){
			echo '<script>window.flat_pm_nonce = "' . wp_create_nonce( 'flat_pm_nonce' ) . '";localStorage.setItem( "visit_f_bool", "false" );</script>';
		}
	}


	function blocks_form(){
		flat_pm_init();
		include_once FLATPM_PATH . '/form.php';
	}

	function add_blocks_form(){
		flat_pm_init();
		include_once FLATPM_PATH . '/form_blocks/add.php';
	}

	function video_form(){
		flat_pm_init();
		include_once FLATPM_PATH . '/form_settings/video.php';
	}

	function header_footer(){
		flat_pm_init();
		include_once FLATPM_PATH . '/form_settings/header_footer.php';
	}

	function block_ip_form(){
		flat_pm_init();
		include_once FLATPM_PATH . '/form_settings/block_ip.php';
	}

	function settings_form(){
		flat_pm_init();
		include_once FLATPM_PATH . '/form_settings/settings.php';
	}

	function export_import(){
		flat_pm_init();
		include_once FLATPM_PATH . '/form_settings/export_import.php';
	}

	function license_form(){
		flat_pm_init();
		include_once FLATPM_PATH . '/form_settings/license.php';
	}


	function flat_admin(){
		register_setting( 'flat_plugin_field', 'flat_plugin_options_me' );

		$option_list = array(
			'flat_plugin_options_me'       => '',
			'flat_plugin_settings_me'      => array(),
			'flat_plugin_header_footer_me' => array(),
			'flat_plugin_video_me'         => array(),
			'flat_pm_cross_color'          => '#ffffff',
			'flat_pm_cross_background'     => '#000000',
			'flat_pm_cross_text_color'     => '#ffffff',
			'flat_pm_cross_offset'         => 'false',
			'flat_pm_cross_width'          => '34',
			'flat_pm_cross_height'         => '34',
			'flat_pm_cross_weight'         => '3',
		);

		foreach ( $option_list as $key => $default ) {
			get_option( $key ) == false && update_option( $key, $default );
		} unset( $default, $key );

		$settings = get_option( 'flat_plugin_settings_me' );
		$cap = ( !isset($settings['editor_manage'] ) || $settings['editor_manage'] != 'true' ) ? 'manage_options' : 'read_private_posts';

		add_menu_page( 'Основные настройки', 'Flat PM', $cap, 'blocks_form', '', FLATPM_LOGO );

		$submenu_list = array(
			'blocks_form'     => 'Ваши блоки',
			'add_blocks_form' => 'Добавить блок',
			'header_footer'   => 'Header и footer',
			'video_form'      => 'Видео прероллы',
			'block_ip_form'   => 'Блокировка ip',
			'settings_form'   => 'Опции плагина',
			'export_import'   => 'Экспорт/импорт',
			'license_form'    => 'Лицензия',
		);

		foreach ( $submenu_list as $key => $value ) {
			add_submenu_page( 'blocks_form', $value, $value, $cap, $key, array( &$this, $key ) );
		} unset( $value, $key );
	}
}

$FlatPM_Obj = new FlatPM_Obj();
?>